@@ -1,6 +1,6 @@
 package Data::Format::Pretty::Console;
 BEGIN {
-  $Data::Format::Pretty::Console::VERSION = '0.02';
+  $Data::Format::Pretty::Console::VERSION = '0.03';
 }
 # ABSTRACT: Pretty-print data structure for console output
 
@@ -117,7 +117,7 @@ sub detect_struct {
             while (my ($k, $v) = each %$data) {
                 my ($s2, $sm2) = detect_struct($v, {skip_hot=>1});
                 last CHECK_HOT unless $s2;
-                $has_t = 1 if $s2 =~ /^(?:list|aoa|aoh)$/;
+                $has_t = 1 if $s2 =~ /^(?:list|aoa|aoh|hash)$/;
             }
             last CHECK_HOT unless $has_t;
             $struct = "hot";
@@ -256,7 +256,7 @@ Data::Format::Pretty::Console - Pretty-print data structure for console output
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
